@@ -1,3 +1,4 @@
+import os
 import itertools
 import tempfile
 from collections import defaultdict
@@ -191,16 +192,25 @@ class Connection(object):
     Represents a Connection to the Shooju api
     """
 
-    def __init__(self, server, user, api_key):
+    def __init__(self, server, *args, **kwargs):
         """
-        Initializes connection with Shooju API
+        Initializes connection with Shooju API.  Must use either user+api_key or email+google_oauth_token to authenticate.
         :param str user: Shooju username
         :param api_key: Shooju API key
+        :param google_oauth_token: Google API refresh token
+        :param email: Google account email
         :param server: Shooju server with protocol (https://alpha2.shooju.com)
         """
-        self._shooju_api = ShoojuApi(server, user, api_key)
+        self._shooju_api = ShoojuApi(server, *args, **kwargs)
         self.job_source = "python"
 
+    @property
+    def user(self):
+        """
+        Returns current user.
+        """
+        return self._shooju_api.client._user
+
     @property
     def raw(self):
         """
@@ -612,10 +622,30 @@ class ShoojuApi(object):
     API_FILES = '/files/{id}/download'
     API_STATUS = '/status/detailed/'
     API_PING = '/status/ping'
+    API_GOOGLE_OAUTH = '/auth/googleoauth'
 
-    def __init__(self, server, user, password):
+    def __init__(self, server, *args, **kwargs):
         url = '{}{}'.format(server, self.API_URL)
-        self.client = Client(url, user, password)
+        if len(args) >= 2:
+            user, api_key = args[:2]
+        else:
+            user, api_key = kwargs.get('user'), kwargs.get('api_key')
+        
+        if not all((user, api_key)):
+            email = kwargs.get('email', os.environ.get('SHOOJU_EMAIL'))
+            google_auth_token = kwargs.get('google_oauth_token', os.environ.get('SHOOJU_GOOGLE_OAUTH_TOKEN'))
+            
+            if email and google_auth_token:
+                anonymous_client = Client(url)
+                credentials = anonymous_client.post(self.API_GOOGLE_OAUTH,
+                                                    data_json={'token': google_auth_token,
+                                                               'email': email})
+                user, api_key = credentials['user'], credentials['api_secret']
+
+        if not all((user, api_key)):
+            raise ShoojuApiError('Must use either user+api_key or email+google_oauth_token to authenticate.')
+
+        self.client = Client(url, user, api_key)
 
     def get_series(self, series_id, date_start=None, date_finish=None, size=10, fields=None):
         """
@@ -793,7 +823,7 @@ class Client(object):
 
     ALLOWED_METHODS = ('get', 'post', 'delete')  # list of allowed HTTP methods
 
-    def __init__(self, url_base, user, password):
+    def __init__(self, url_base, user=None, password=None):
         """
         REST Client
 
